==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/Line2P/ts/Line2P_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Line2P</name>
    <message>
        <location filename="../Line2P.js" line="+67"/>
        <source>First point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Line2P.ui" line="+23"/>
        <source>Close Sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Restrict length or angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Line2PInit.js" line="+2"/>
        <source>Line from &amp;2 Points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single line or sequence of lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/Line2P/ts/Line2P_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Line2P</name>
    <message>
        <location filename="../Line2P.js" line="+67"/>
        <source>First point</source>
        <translation>První bod</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next point</source>
        <translation>Další bod</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../Line2P.ui" line="+23"/>
        <source>Close Sequence</source>
        <translation>Uzavřít sekvenci</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, C</source>
        <translation>,, C</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translation>Zrušit předchozí segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation>,, U</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation>Vrátit segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation>,, R</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Restrict length or angle</source>
        <translation>Omezit délku nebo úhel</translation>
    </message>
    <message>
        <location filename="../Line2PInit.js" line="+2"/>
        <source>Line from &amp;2 Points</source>
        <translation>Úsečka zadaná &amp;2 body</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single line or sequence of lines</source>
        <translation>Kreslit jednu úsečku nebo sekvenci úseček</translation>
    </message>
</context>
</TS>
